@@ -124,8 +124,8 @@ class SecretsManagerClient(BaseClient):
         KmsKeyId: str = ...,
         SecretBinary: Union[str, bytes, IO[Any], StreamingBody] = ...,
         SecretString: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
-        AddReplicaRegions: Sequence["ReplicaRegionTypeTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
+        AddReplicaRegions: Sequence[ReplicaRegionTypeTypeDef] = ...,
         ForceOverwriteReplicaSecret: bool = ...
     ) -> CreateSecretResponseTypeDef:
         """
@@ -238,7 +238,7 @@ class SecretsManagerClient(BaseClient):
         *,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         SortOrder: SortOrderTypeType = ...
     ) -> ListSecretsResponseTypeDef:
         """
@@ -290,7 +290,7 @@ class SecretsManagerClient(BaseClient):
         self,
         *,
         SecretId: str,
-        AddReplicaRegions: Sequence["ReplicaRegionTypeTypeDef"],
+        AddReplicaRegions: Sequence[ReplicaRegionTypeTypeDef],
         ForceOverwriteReplicaSecret: bool = ...
     ) -> ReplicateSecretToRegionsResponseTypeDef:
         """
@@ -315,7 +315,7 @@ class SecretsManagerClient(BaseClient):
         SecretId: str,
         ClientRequestToken: str = ...,
         RotationLambdaARN: str = ...,
-        RotationRules: "RotationRulesTypeTypeDef" = ...,
+        RotationRules: RotationRulesTypeTypeDef = ...,
         RotateImmediately: bool = ...
     ) -> RotateSecretResponseTypeDef:
         """
@@ -336,7 +336,7 @@ class SecretsManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#stop_replication_to_replica)
         """
 
-    def tag_resource(self, *, SecretId: str, Tags: Sequence["TagTypeDef"]) -> None:
+    def tag_resource(self, *, SecretId: str, Tags: Sequence[TagTypeDef]) -> None:
         """
         Attaches tags to a secret.
 
