@@ -27,58 +27,58 @@ else:
 
 __all__ = (
     "CancelRotateSecretRequestRequestTypeDef",
-    "CancelRotateSecretResponseTypeDef",
-    "CreateSecretRequestRequestTypeDef",
-    "CreateSecretResponseTypeDef",
+    "ResponseMetadataTypeDef",
+    "ReplicaRegionTypeTypeDef",
+    "TagTypeDef",
+    "ReplicationStatusTypeTypeDef",
     "DeleteResourcePolicyRequestRequestTypeDef",
-    "DeleteResourcePolicyResponseTypeDef",
     "DeleteSecretRequestRequestTypeDef",
-    "DeleteSecretResponseTypeDef",
     "DescribeSecretRequestRequestTypeDef",
-    "DescribeSecretResponseTypeDef",
+    "RotationRulesTypeTypeDef",
     "FilterTypeDef",
     "GetRandomPasswordRequestRequestTypeDef",
-    "GetRandomPasswordResponseTypeDef",
     "GetResourcePolicyRequestRequestTypeDef",
-    "GetResourcePolicyResponseTypeDef",
     "GetSecretValueRequestRequestTypeDef",
-    "GetSecretValueResponseTypeDef",
     "ListSecretVersionIdsRequestRequestTypeDef",
-    "ListSecretVersionIdsResponseTypeDef",
-    "ListSecretsRequestListSecretsPaginateTypeDef",
-    "ListSecretsRequestRequestTypeDef",
-    "ListSecretsResponseTypeDef",
+    "SecretVersionsListEntryTypeDef",
     "PaginatorConfigTypeDef",
     "PutResourcePolicyRequestRequestTypeDef",
-    "PutResourcePolicyResponseTypeDef",
     "PutSecretValueRequestRequestTypeDef",
-    "PutSecretValueResponseTypeDef",
     "RemoveRegionsFromReplicationRequestRequestTypeDef",
-    "RemoveRegionsFromReplicationResponseTypeDef",
-    "ReplicaRegionTypeTypeDef",
-    "ReplicateSecretToRegionsRequestRequestTypeDef",
-    "ReplicateSecretToRegionsResponseTypeDef",
-    "ReplicationStatusTypeTypeDef",
-    "ResponseMetadataTypeDef",
     "RestoreSecretRequestRequestTypeDef",
-    "RestoreSecretResponseTypeDef",
-    "RotateSecretRequestRequestTypeDef",
-    "RotateSecretResponseTypeDef",
-    "RotationRulesTypeTypeDef",
-    "SecretListEntryTypeDef",
-    "SecretVersionsListEntryTypeDef",
     "StopReplicationToReplicaRequestRequestTypeDef",
-    "StopReplicationToReplicaResponseTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateSecretRequestRequestTypeDef",
-    "UpdateSecretResponseTypeDef",
     "UpdateSecretVersionStageRequestRequestTypeDef",
-    "UpdateSecretVersionStageResponseTypeDef",
     "ValidateResourcePolicyRequestRequestTypeDef",
-    "ValidateResourcePolicyResponseTypeDef",
     "ValidationErrorsEntryTypeDef",
+    "CancelRotateSecretResponseTypeDef",
+    "DeleteResourcePolicyResponseTypeDef",
+    "DeleteSecretResponseTypeDef",
+    "GetRandomPasswordResponseTypeDef",
+    "GetResourcePolicyResponseTypeDef",
+    "GetSecretValueResponseTypeDef",
+    "PutResourcePolicyResponseTypeDef",
+    "PutSecretValueResponseTypeDef",
+    "RestoreSecretResponseTypeDef",
+    "RotateSecretResponseTypeDef",
+    "StopReplicationToReplicaResponseTypeDef",
+    "UpdateSecretResponseTypeDef",
+    "UpdateSecretVersionStageResponseTypeDef",
+    "ReplicateSecretToRegionsRequestRequestTypeDef",
+    "CreateSecretRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "CreateSecretResponseTypeDef",
+    "RemoveRegionsFromReplicationResponseTypeDef",
+    "ReplicateSecretToRegionsResponseTypeDef",
+    "DescribeSecretResponseTypeDef",
+    "RotateSecretRequestRequestTypeDef",
+    "SecretListEntryTypeDef",
+    "ListSecretsRequestRequestTypeDef",
+    "ListSecretVersionIdsResponseTypeDef",
+    "ListSecretsRequestListSecretsPaginateTypeDef",
+    "ValidateResourcePolicyResponseTypeDef",
+    "ListSecretsResponseTypeDef",
 )
 
 CancelRotateSecretRequestRequestTypeDef = TypedDict(
@@ -88,53 +88,45 @@ CancelRotateSecretRequestRequestTypeDef = TypedDict(
     },
 )
 
-CancelRotateSecretResponseTypeDef = TypedDict(
-    "CancelRotateSecretResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "ARN": str,
-        "Name": str,
-        "VersionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-_RequiredCreateSecretRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateSecretRequestRequestTypeDef",
+ReplicaRegionTypeTypeDef = TypedDict(
+    "ReplicaRegionTypeTypeDef",
     {
-        "Name": str,
-    },
-)
-_OptionalCreateSecretRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateSecretRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "Description": str,
+        "Region": str,
         "KmsKeyId": str,
-        "SecretBinary": Union[str, bytes, IO[Any], StreamingBody],
-        "SecretString": str,
-        "Tags": Sequence["TagTypeDef"],
-        "AddReplicaRegions": Sequence["ReplicaRegionTypeTypeDef"],
-        "ForceOverwriteReplicaSecret": bool,
     },
     total=False,
 )
 
-
-class CreateSecretRequestRequestTypeDef(
-    _RequiredCreateSecretRequestRequestTypeDef, _OptionalCreateSecretRequestRequestTypeDef
-):
-    pass
-
-
-CreateSecretResponseTypeDef = TypedDict(
-    "CreateSecretResponseTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "ARN": str,
-        "Name": str,
-        "VersionId": str,
-        "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Key": str,
+        "Value": str,
     },
+    total=False,
+)
+
+ReplicationStatusTypeTypeDef = TypedDict(
+    "ReplicationStatusTypeTypeDef",
+    {
+        "Region": str,
+        "KmsKeyId": str,
+        "Status": StatusTypeType,
+        "StatusMessage": str,
+        "LastAccessedDate": datetime,
+    },
+    total=False,
 )
 
 DeleteResourcePolicyRequestRequestTypeDef = TypedDict(
@@ -144,15 +136,6 @@ DeleteResourcePolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteResourcePolicyResponseTypeDef = TypedDict(
-    "DeleteResourcePolicyResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredDeleteSecretRequestRequestTypeDef = TypedDict(
     "_RequiredDeleteSecretRequestRequestTypeDef",
     {
@@ -175,16 +158,6 @@ class DeleteSecretRequestRequestTypeDef(
     pass
 
 
-DeleteSecretResponseTypeDef = TypedDict(
-    "DeleteSecretResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "DeletionDate": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeSecretRequestRequestTypeDef = TypedDict(
     "DescribeSecretRequestRequestTypeDef",
     {
@@ -192,28 +165,14 @@ DescribeSecretRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeSecretResponseTypeDef = TypedDict(
-    "DescribeSecretResponseTypeDef",
+RotationRulesTypeTypeDef = TypedDict(
+    "RotationRulesTypeTypeDef",
     {
-        "ARN": str,
-        "Name": str,
-        "Description": str,
-        "KmsKeyId": str,
-        "RotationEnabled": bool,
-        "RotationLambdaARN": str,
-        "RotationRules": "RotationRulesTypeTypeDef",
-        "LastRotatedDate": datetime,
-        "LastChangedDate": datetime,
-        "LastAccessedDate": datetime,
-        "DeletedDate": datetime,
-        "Tags": List["TagTypeDef"],
-        "VersionIdsToStages": Dict[str, List[str]],
-        "OwningService": str,
-        "CreatedDate": datetime,
-        "PrimaryRegion": str,
-        "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "AutomaticallyAfterDays": int,
+        "Duration": str,
+        "ScheduleExpression": str,
     },
+    total=False,
 )
 
 FilterTypeDef = TypedDict(
@@ -240,14 +199,6 @@ GetRandomPasswordRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetRandomPasswordResponseTypeDef = TypedDict(
-    "GetRandomPasswordResponseTypeDef",
-    {
-        "RandomPassword": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetResourcePolicyRequestRequestTypeDef = TypedDict(
     "GetResourcePolicyRequestRequestTypeDef",
     {
@@ -255,16 +206,6 @@ GetResourcePolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetResourcePolicyResponseTypeDef = TypedDict(
-    "GetResourcePolicyResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "ResourcePolicy": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetSecretValueRequestRequestTypeDef = TypedDict(
     "_RequiredGetSecretValueRequestRequestTypeDef",
     {
@@ -287,20 +228,6 @@ class GetSecretValueRequestRequestTypeDef(
     pass
 
 
-GetSecretValueResponseTypeDef = TypedDict(
-    "GetSecretValueResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "VersionId": str,
-        "SecretBinary": bytes,
-        "SecretString": str,
-        "VersionStages": List[str],
-        "CreatedDate": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListSecretVersionIdsRequestRequestTypeDef = TypedDict(
     "_RequiredListSecretVersionIdsRequestRequestTypeDef",
     {
@@ -325,47 +252,18 @@ class ListSecretVersionIdsRequestRequestTypeDef(
     pass
 
 
-ListSecretVersionIdsResponseTypeDef = TypedDict(
-    "ListSecretVersionIdsResponseTypeDef",
+SecretVersionsListEntryTypeDef = TypedDict(
+    "SecretVersionsListEntryTypeDef",
     {
-        "Versions": List["SecretVersionsListEntryTypeDef"],
-        "NextToken": str,
-        "ARN": str,
-        "Name": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListSecretsRequestListSecretsPaginateTypeDef = TypedDict(
-    "ListSecretsRequestListSecretsPaginateTypeDef",
-    {
-        "Filters": Sequence["FilterTypeDef"],
-        "SortOrder": SortOrderTypeType,
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "VersionId": str,
+        "VersionStages": List[str],
+        "LastAccessedDate": datetime,
+        "CreatedDate": datetime,
+        "KmsKeyIds": List[str],
     },
     total=False,
 )
 
-ListSecretsRequestRequestTypeDef = TypedDict(
-    "ListSecretsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-        "Filters": Sequence["FilterTypeDef"],
-        "SortOrder": SortOrderTypeType,
-    },
-    total=False,
-)
-
-ListSecretsResponseTypeDef = TypedDict(
-    "ListSecretsResponseTypeDef",
-    {
-        "SecretList": List["SecretListEntryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -398,15 +296,6 @@ class PutResourcePolicyRequestRequestTypeDef(
     pass
 
 
-PutResourcePolicyResponseTypeDef = TypedDict(
-    "PutResourcePolicyResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredPutSecretValueRequestRequestTypeDef = TypedDict(
     "_RequiredPutSecretValueRequestRequestTypeDef",
     {
@@ -431,17 +320,6 @@ class PutSecretValueRequestRequestTypeDef(
     pass
 
 
-PutSecretValueResponseTypeDef = TypedDict(
-    "PutSecretValueResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "VersionId": str,
-        "VersionStages": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 RemoveRegionsFromReplicationRequestRequestTypeDef = TypedDict(
     "RemoveRegionsFromReplicationRequestRequestTypeDef",
     {
@@ -450,79 +328,6 @@ RemoveRegionsFromReplicationRequestRequestTypeDef = TypedDict(
     },
 )
 
-RemoveRegionsFromReplicationResponseTypeDef = TypedDict(
-    "RemoveRegionsFromReplicationResponseTypeDef",
-    {
-        "ARN": str,
-        "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ReplicaRegionTypeTypeDef = TypedDict(
-    "ReplicaRegionTypeTypeDef",
-    {
-        "Region": str,
-        "KmsKeyId": str,
-    },
-    total=False,
-)
-
-_RequiredReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
-    "_RequiredReplicateSecretToRegionsRequestRequestTypeDef",
-    {
-        "SecretId": str,
-        "AddReplicaRegions": Sequence["ReplicaRegionTypeTypeDef"],
-    },
-)
-_OptionalReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
-    "_OptionalReplicateSecretToRegionsRequestRequestTypeDef",
-    {
-        "ForceOverwriteReplicaSecret": bool,
-    },
-    total=False,
-)
-
-
-class ReplicateSecretToRegionsRequestRequestTypeDef(
-    _RequiredReplicateSecretToRegionsRequestRequestTypeDef,
-    _OptionalReplicateSecretToRegionsRequestRequestTypeDef,
-):
-    pass
-
-
-ReplicateSecretToRegionsResponseTypeDef = TypedDict(
-    "ReplicateSecretToRegionsResponseTypeDef",
-    {
-        "ARN": str,
-        "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ReplicationStatusTypeTypeDef = TypedDict(
-    "ReplicationStatusTypeTypeDef",
-    {
-        "Region": str,
-        "KmsKeyId": str,
-        "Status": StatusTypeType,
-        "StatusMessage": str,
-        "LastAccessedDate": datetime,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 RestoreSecretRequestRequestTypeDef = TypedDict(
     "RestoreSecretRequestRequestTypeDef",
     {
@@ -530,94 +335,6 @@ RestoreSecretRequestRequestTypeDef = TypedDict(
     },
 )
 
-RestoreSecretResponseTypeDef = TypedDict(
-    "RestoreSecretResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredRotateSecretRequestRequestTypeDef = TypedDict(
-    "_RequiredRotateSecretRequestRequestTypeDef",
-    {
-        "SecretId": str,
-    },
-)
-_OptionalRotateSecretRequestRequestTypeDef = TypedDict(
-    "_OptionalRotateSecretRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "RotationLambdaARN": str,
-        "RotationRules": "RotationRulesTypeTypeDef",
-        "RotateImmediately": bool,
-    },
-    total=False,
-)
-
-
-class RotateSecretRequestRequestTypeDef(
-    _RequiredRotateSecretRequestRequestTypeDef, _OptionalRotateSecretRequestRequestTypeDef
-):
-    pass
-
-
-RotateSecretResponseTypeDef = TypedDict(
-    "RotateSecretResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "VersionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-RotationRulesTypeTypeDef = TypedDict(
-    "RotationRulesTypeTypeDef",
-    {
-        "AutomaticallyAfterDays": int,
-        "Duration": str,
-        "ScheduleExpression": str,
-    },
-    total=False,
-)
-
-SecretListEntryTypeDef = TypedDict(
-    "SecretListEntryTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "Description": str,
-        "KmsKeyId": str,
-        "RotationEnabled": bool,
-        "RotationLambdaARN": str,
-        "RotationRules": "RotationRulesTypeTypeDef",
-        "LastRotatedDate": datetime,
-        "LastChangedDate": datetime,
-        "LastAccessedDate": datetime,
-        "DeletedDate": datetime,
-        "Tags": List["TagTypeDef"],
-        "SecretVersionsToStages": Dict[str, List[str]],
-        "OwningService": str,
-        "CreatedDate": datetime,
-        "PrimaryRegion": str,
-    },
-    total=False,
-)
-
-SecretVersionsListEntryTypeDef = TypedDict(
-    "SecretVersionsListEntryTypeDef",
-    {
-        "VersionId": str,
-        "VersionStages": List[str],
-        "LastAccessedDate": datetime,
-        "CreatedDate": datetime,
-        "KmsKeyIds": List[str],
-    },
-    total=False,
-)
-
 StopReplicationToReplicaRequestRequestTypeDef = TypedDict(
     "StopReplicationToReplicaRequestRequestTypeDef",
     {
@@ -625,31 +342,6 @@ StopReplicationToReplicaRequestRequestTypeDef = TypedDict(
     },
 )
 
-StopReplicationToReplicaResponseTypeDef = TypedDict(
-    "StopReplicationToReplicaResponseTypeDef",
-    {
-        "ARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "SecretId": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-)
-
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "Key": str,
-        "Value": str,
-    },
-    total=False,
-)
-
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -683,16 +375,6 @@ class UpdateSecretRequestRequestTypeDef(
     pass
 
 
-UpdateSecretResponseTypeDef = TypedDict(
-    "UpdateSecretResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "VersionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateSecretVersionStageRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateSecretVersionStageRequestRequestTypeDef",
     {
@@ -717,15 +399,6 @@ class UpdateSecretVersionStageRequestRequestTypeDef(
     pass
 
 
-UpdateSecretVersionStageResponseTypeDef = TypedDict(
-    "UpdateSecretVersionStageResponseTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredValidateResourcePolicyRequestRequestTypeDef = TypedDict(
     "_RequiredValidateResourcePolicyRequestRequestTypeDef",
     {
@@ -748,15 +421,6 @@ class ValidateResourcePolicyRequestRequestTypeDef(
     pass
 
 
-ValidateResourcePolicyResponseTypeDef = TypedDict(
-    "ValidateResourcePolicyResponseTypeDef",
-    {
-        "PolicyValidationPassed": bool,
-        "ValidationErrors": List["ValidationErrorsEntryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ValidationErrorsEntryTypeDef = TypedDict(
     "ValidationErrorsEntryTypeDef",
     {
@@ -765,3 +429,339 @@ ValidationErrorsEntryTypeDef = TypedDict(
     },
     total=False,
 )
+
+CancelRotateSecretResponseTypeDef = TypedDict(
+    "CancelRotateSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteResourcePolicyResponseTypeDef = TypedDict(
+    "DeleteResourcePolicyResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteSecretResponseTypeDef = TypedDict(
+    "DeleteSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "DeletionDate": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetRandomPasswordResponseTypeDef = TypedDict(
+    "GetRandomPasswordResponseTypeDef",
+    {
+        "RandomPassword": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetResourcePolicyResponseTypeDef = TypedDict(
+    "GetResourcePolicyResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "ResourcePolicy": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetSecretValueResponseTypeDef = TypedDict(
+    "GetSecretValueResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "SecretBinary": bytes,
+        "SecretString": str,
+        "VersionStages": List[str],
+        "CreatedDate": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutResourcePolicyResponseTypeDef = TypedDict(
+    "PutResourcePolicyResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutSecretValueResponseTypeDef = TypedDict(
+    "PutSecretValueResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "VersionStages": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RestoreSecretResponseTypeDef = TypedDict(
+    "RestoreSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RotateSecretResponseTypeDef = TypedDict(
+    "RotateSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StopReplicationToReplicaResponseTypeDef = TypedDict(
+    "StopReplicationToReplicaResponseTypeDef",
+    {
+        "ARN": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateSecretResponseTypeDef = TypedDict(
+    "UpdateSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateSecretVersionStageResponseTypeDef = TypedDict(
+    "UpdateSecretVersionStageResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
+    "_RequiredReplicateSecretToRegionsRequestRequestTypeDef",
+    {
+        "SecretId": str,
+        "AddReplicaRegions": Sequence[ReplicaRegionTypeTypeDef],
+    },
+)
+_OptionalReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
+    "_OptionalReplicateSecretToRegionsRequestRequestTypeDef",
+    {
+        "ForceOverwriteReplicaSecret": bool,
+    },
+    total=False,
+)
+
+
+class ReplicateSecretToRegionsRequestRequestTypeDef(
+    _RequiredReplicateSecretToRegionsRequestRequestTypeDef,
+    _OptionalReplicateSecretToRegionsRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredCreateSecretRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSecretRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalCreateSecretRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSecretRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "Description": str,
+        "KmsKeyId": str,
+        "SecretBinary": Union[str, bytes, IO[Any], StreamingBody],
+        "SecretString": str,
+        "Tags": Sequence[TagTypeDef],
+        "AddReplicaRegions": Sequence[ReplicaRegionTypeTypeDef],
+        "ForceOverwriteReplicaSecret": bool,
+    },
+    total=False,
+)
+
+
+class CreateSecretRequestRequestTypeDef(
+    _RequiredCreateSecretRequestRequestTypeDef, _OptionalCreateSecretRequestRequestTypeDef
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "SecretId": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateSecretResponseTypeDef = TypedDict(
+    "CreateSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "VersionId": str,
+        "ReplicationStatus": List[ReplicationStatusTypeTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RemoveRegionsFromReplicationResponseTypeDef = TypedDict(
+    "RemoveRegionsFromReplicationResponseTypeDef",
+    {
+        "ARN": str,
+        "ReplicationStatus": List[ReplicationStatusTypeTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ReplicateSecretToRegionsResponseTypeDef = TypedDict(
+    "ReplicateSecretToRegionsResponseTypeDef",
+    {
+        "ARN": str,
+        "ReplicationStatus": List[ReplicationStatusTypeTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeSecretResponseTypeDef = TypedDict(
+    "DescribeSecretResponseTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "Description": str,
+        "KmsKeyId": str,
+        "RotationEnabled": bool,
+        "RotationLambdaARN": str,
+        "RotationRules": RotationRulesTypeTypeDef,
+        "LastRotatedDate": datetime,
+        "LastChangedDate": datetime,
+        "LastAccessedDate": datetime,
+        "DeletedDate": datetime,
+        "Tags": List[TagTypeDef],
+        "VersionIdsToStages": Dict[str, List[str]],
+        "OwningService": str,
+        "CreatedDate": datetime,
+        "PrimaryRegion": str,
+        "ReplicationStatus": List[ReplicationStatusTypeTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredRotateSecretRequestRequestTypeDef = TypedDict(
+    "_RequiredRotateSecretRequestRequestTypeDef",
+    {
+        "SecretId": str,
+    },
+)
+_OptionalRotateSecretRequestRequestTypeDef = TypedDict(
+    "_OptionalRotateSecretRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "RotationLambdaARN": str,
+        "RotationRules": RotationRulesTypeTypeDef,
+        "RotateImmediately": bool,
+    },
+    total=False,
+)
+
+
+class RotateSecretRequestRequestTypeDef(
+    _RequiredRotateSecretRequestRequestTypeDef, _OptionalRotateSecretRequestRequestTypeDef
+):
+    pass
+
+
+SecretListEntryTypeDef = TypedDict(
+    "SecretListEntryTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "Description": str,
+        "KmsKeyId": str,
+        "RotationEnabled": bool,
+        "RotationLambdaARN": str,
+        "RotationRules": RotationRulesTypeTypeDef,
+        "LastRotatedDate": datetime,
+        "LastChangedDate": datetime,
+        "LastAccessedDate": datetime,
+        "DeletedDate": datetime,
+        "Tags": List[TagTypeDef],
+        "SecretVersionsToStages": Dict[str, List[str]],
+        "OwningService": str,
+        "CreatedDate": datetime,
+        "PrimaryRegion": str,
+    },
+    total=False,
+)
+
+ListSecretsRequestRequestTypeDef = TypedDict(
+    "ListSecretsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "Filters": Sequence[FilterTypeDef],
+        "SortOrder": SortOrderTypeType,
+    },
+    total=False,
+)
+
+ListSecretVersionIdsResponseTypeDef = TypedDict(
+    "ListSecretVersionIdsResponseTypeDef",
+    {
+        "Versions": List[SecretVersionsListEntryTypeDef],
+        "NextToken": str,
+        "ARN": str,
+        "Name": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListSecretsRequestListSecretsPaginateTypeDef = TypedDict(
+    "ListSecretsRequestListSecretsPaginateTypeDef",
+    {
+        "Filters": Sequence[FilterTypeDef],
+        "SortOrder": SortOrderTypeType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ValidateResourcePolicyResponseTypeDef = TypedDict(
+    "ValidateResourcePolicyResponseTypeDef",
+    {
+        "PolicyValidationPassed": bool,
+        "ValidationErrors": List[ValidationErrorsEntryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListSecretsResponseTypeDef = TypedDict(
+    "ListSecretsResponseTypeDef",
+    {
+        "SecretList": List[SecretListEntryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
